Part I. Getting Started

# XMLRésuméLibrary: User Guide

Introduction | XML Résumé Library User Guide | Setting up the XML Résumé Library

# Getting Started

Table of Contents

1. Setting up the XML Résumé Library
  Prerequisites
  Getting the Software
  Installing and Configuring the Software
2. Exploring the Features of XML Résumé Library
  Formatting an example resume
  Advanced Features of the XML Résumé Library
  Writing your first XML Résumé
  Where to Go from Here
  About this chapter

Introduction | XML Résumé Library User Guide | Setting up the XML Résumé Library